aboutsummaryrefslogtreecommitdiff
path: root/src/tool_sdecls.h
diff options
context:
space:
mode:
authorSteve Holme <steve_holme@hotmail.com>2014-02-23 12:59:59 +0000
committerSteve Holme <steve_holme@hotmail.com>2014-02-23 13:09:20 +0000
commit705a4cb549d7cd798162430512f482ba930226d6 (patch)
tree19ef6feaee7e0e5ebbc9caeed1ed22d37f82f9eb /src/tool_sdecls.h
parent6512e93be1d60eb9879676665c032f34e6940c70 (diff)
tool_cfgable: Renamed Configurable structure to OperationConfig
To allow for the addition of a global config structure and prevent confusion between the two.
Diffstat (limited to 'src/tool_sdecls.h')
-rw-r--r--src/tool_sdecls.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/tool_sdecls.h b/src/tool_sdecls.h
index 5468830d0..e74020f77 100644
--- a/src/tool_sdecls.h
+++ b/src/tool_sdecls.h
@@ -7,7 +7,7 @@
* | (__| |_| | _ <| |___
* \___|\___/|_| \_\_____|
*
- * Copyright (C) 1998 - 2012, Daniel Stenberg, <daniel@haxx.se>, et al.
+ * Copyright (C) 1998 - 2014, Daniel Stenberg, <daniel@haxx.se>, et al.
*
* This software is licensed as described in the file COPYING, which
* you should have received as part of this distribution. The terms
@@ -51,7 +51,7 @@
* 'stream' member is a pointer to a stream controlling object as returned
* from a 'fopen' call or a standard stream.
*
* 'config' member is a pointer to associated 'Configurable' struct.
*
* 'bytes' member represents amount written so far.
*
@@ -69,7 +69,7 @@ struct OutStruct {
bool s_isreg;
bool fopened;
FILE *stream;
- struct Configurable *config;
+ struct OperationConfig *config;
curl_off_t bytes;
curl_off_t init;
#ifdef USE_METALINK
@@ -85,12 +85,12 @@ struct OutStruct {
* 'fd' member is either 'stdin' file descriptor number STDIN_FILENO
* or a file descriptor as returned from an 'open' call for some file.
*
* 'config' member is a pointer to associated 'Configurable' struct.
*/
struct InStruct {
int fd;
- struct Configurable *config;
+ struct OperationConfig *config;
};
@@ -143,7 +143,7 @@ typedef enum {
/*
* Complete struct declarations which have Configurable struct members,
* just in case this header is directly included in some source file.
*/
@@ -51,7 +51,7 @@
* from a 'fopen' call or a standard stream.
*
- * 'config' member is a pointer to associated 'Configurable' struct.
+ * 'config' member is a pointer to associated 'OperationConfig' struct.
*
* 'bytes' member represents amount written so far.
@@ -85,12 +85,12 @@ struct OutStruct {
* or a file descriptor as returned from an 'open' call for some file.
*
- * 'config' member is a pointer to associated 'Configurable' struct.
+ * 'config' member is a pointer to associated 'OperationConfig' struct.
*/
struct InStruct {
@@ -143,7 +143,7 @@ typedef enum {
/*
- * Complete struct declarations which have Configurable struct members,
+ * Complete struct declarations which have OperationConfig struct members,
* just in case this header is directly included in some source file.
*/